@@ -68,19 +68,46 @@ UpdateRoutingControlStateEntryTypeDef = TypedDict(
     },
 )
 
-UpdateRoutingControlStateRequestRequestTypeDef = TypedDict(
-    "UpdateRoutingControlStateRequestRequestTypeDef",
+_RequiredUpdateRoutingControlStateRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateRoutingControlStateRequestRequestTypeDef",
     {
         "RoutingControlArn": str,
         "RoutingControlState": RoutingControlStateType,
-        "SafetyRulesToOverride": NotRequired[Sequence[str]],
     },
 )
+_OptionalUpdateRoutingControlStateRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateRoutingControlStateRequestRequestTypeDef",
+    {
+        "SafetyRulesToOverride": Sequence[str],
+    },
+    total=False,
+)
 
-UpdateRoutingControlStatesRequestRequestTypeDef = TypedDict(
-    "UpdateRoutingControlStatesRequestRequestTypeDef",
+
+class UpdateRoutingControlStateRequestRequestTypeDef(
+    _RequiredUpdateRoutingControlStateRequestRequestTypeDef,
+    _OptionalUpdateRoutingControlStateRequestRequestTypeDef,
+):
+    pass
+
+
+_RequiredUpdateRoutingControlStatesRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateRoutingControlStatesRequestRequestTypeDef",
     {
         "UpdateRoutingControlStateEntries": Sequence["UpdateRoutingControlStateEntryTypeDef"],
-        "SafetyRulesToOverride": NotRequired[Sequence[str]],
     },
 )
+_OptionalUpdateRoutingControlStatesRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateRoutingControlStatesRequestRequestTypeDef",
+    {
+        "SafetyRulesToOverride": Sequence[str],
+    },
+    total=False,
+)
+
+
+class UpdateRoutingControlStatesRequestRequestTypeDef(
+    _RequiredUpdateRoutingControlStatesRequestRequestTypeDef,
+    _OptionalUpdateRoutingControlStatesRequestRequestTypeDef,
+):
+    pass
